#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" Mapycs (Matics Python API) usage example """

import os
import re

from mapycs import Dataframe
import test_eval

PATH = r"/media/sab/Windows/data/eval_2_all"
JPG_PATTERN = r"^.*\.jpg$"
REF_PATTERN = r"^.*\.xml$"
HYP_PATTERN = r"^.*\.xml$"
PGM_PATTERN = r"^.*\.pgm$"
PROJECTS = ["bipbip", "pead", "roseau", "weedelec"]
PROJECTS = ["pead"]
PLANTS = ["haricot", "mais"]
RELOAD = True


def get_files(path, pattern):

    """ Populate hypothesis files list """

    files = []
    name_pattern = re.compile(pattern)
    for file_name in os.listdir(path):
        if name_pattern.match(file_name) is None:
            continue
        file_path = os.path.join(path, file_name)
        files.append(file_path)
    files.sort()
    return files


def main():

    """ Dataframe usage examples """

    for project in PROJECTS:

        jpg_files = []
        ref_files = []
        hyp_files = []
        pgm_files = []

        for plant in PLANTS:

            path = os.path.join(PATH, project)

            jpg_path = os.path.join(path, "images", plant)
            jpg_files += get_files(jpg_path, JPG_PATTERN)

            ref_path = os.path.join(path, "annotations", "ref", plant)
            ref_files += get_files(ref_path, REF_PATTERN)

            hyp_path = os.path.join(path, "annotations", "hyp", plant)
            hyp_files += get_files(hyp_path, HYP_PATTERN)

            pgm_path = os.path.join(path, "annotations", "masques", plant)
            pgm_files += get_files(pgm_path, PGM_PATTERN)

        name = "det_{}".format(project)

        # Ref
        print("=" * 80)
        print("Loading ref")
        file_path = "/tmp/{}_ref.dtf".format(name)
        if RELOAD and os.path.exists(file_path):
            print("From {}".format(file_path))
            ref = Dataframe.from_file(file_path)
        else:
            print("From {} annotation files".format(len(ref_files)))
            ref = Dataframe()
            for ref_file in ref_files:
    #                print("\t{}".format(ref_file))
                ref.load_annot(ref_file)
            print("-" * 80)
            print("Adding medias")
            ref.add_medias(jpg_files)
            print("-" * 80)
            print("Saving to {}".format(file_path))
            ref.save(file_path)
        print("-" * 80)
        print(ref)

        # Hyp
        print("=" * 80)
        print("Loading hyp")
        file_path = "/tmp/{}_hyp.dtf".format(name)
        if RELOAD and os.path.exists(file_path):
            print("From {}".format(file_path))
            hyp = Dataframe.from_file(file_path)
        else:
            print("From {} annotation files".format(len(hyp_files)))
            hyp = Dataframe()
            for hyp_file in hyp_files:
                system = project
    #                print("\t{}".format(hyp_file))
                params = {"systeme": system}
                hyp.load_annot(hyp_file, params)
            print("-" * 80)
            print("Adding medias")
            hyp.add_medias(pgm_files + jpg_files)
            print("-" * 80)
            print("Saving to {}".format(file_path))
            hyp.save(file_path)
        print("-" * 80)
        print(hyp)

        categories = [["global.system"], ["plant.class", "plant.name"]]
        variables = ["plant.correct", "plant.confusion",
                     "plant.false alarm", "plant.miss", "plant.eger"]
        params_list = [
            None,
            {"params": {"fa_cost": 2, "miss_cost": 0.5, "conf_cost": 3}}
        ]
        test_eval.test_eval("det", params_list, ref, hyp,
                            categories, variables, name)


if __name__ == "__main__":

    main()
