#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" Mapycs (Matics Python API) usage example """

import os

from mapycs import Dataframe
import test_eval

PATH = os.environ.get(r'HOME') + r"/matics/data/EN"


def main():

    """ Dataframe usage examples """

    # Ref
    print("=" * 80)
    print("Loading ref")
    ref_path = os.path.join(PATH, "ref/conll2003_eng.dtf")
    ref = Dataframe.from_file(ref_path)
    print("-" * 80)
    print(ref)


#    # Hyp
    print("=" * 80)
    print("Loading hyp")
    hyp_path = os.path.join(PATH, "hyp/spacy/spacy.dtf")
    hyp = Dataframe.from_file(hyp_path)
    print("-" * 80)
    print(hyp)

    categories = [["global.system"], ["global.file"]]
    variables = ["slot.insertion cost", "slot.deletion cost",
                 "slot.substitution cost", "slot.correct count",
                 "slot.hypothesis count", "slot.ser", "slot.precision",
                 "slot.recall", "slot.f-measure",
                 "single bleu.score", "multi bleu.score",
                 "ter.best reference score"]
    params_list = [
        {"params": {"mapref": os.path.join(PATH, "map/CoNLL2003.map"),
                    "maphyp": os.path.join(PATH, "map/polyglot_spacy.map")}}
    ]
    test_eval.test_eval("ent", params_list, ref, hyp, categories, variables)


if __name__ == "__main__":

    main()
