#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" Mapycs (Matics Python API) usage example """

import os
import re

from mapycs import Dataframe
import test_eval

PATH = r"/home/sab/rose/inter-intra"
JPG_PATTERN = r"^.*\.jpg$"
REF_PATTERN = r"^.*\.xml$"
HYP_PATTERN = r"^.*\.xml$"
PGM_PATTERN = r"^.*\.pgm$"
PROJECTS = ["Bipbip", "Pead", "Roseau", "Weedelec"]
PLANTS = ["Haricot", "Mais"]
RELOAD = True


def get_files(path, pattern):

    """ Populate hypothesis files list """

    files = []
    name_pattern = re.compile(pattern)
    for file_name in os.listdir(path):
        if name_pattern.match(file_name) is None:
            continue
        file_path = os.path.join(path, file_name)
        files.append(file_path)
    files.sort()
    return files


def main():

    """ Dataframe usage examples """

    # Src
    print("=" * 80)
    print("Loading src")
    file_path = "/tmp/iag_src.dtf"
    if RELOAD and os.path.exists(file_path):
        print("From {}".format(file_path))
        src = Dataframe.from_file(file_path)
    else:
        jpg_files = []
        for project in PROJECTS:
            for plant in PLANTS:
                jpg_path = os.path.join(PATH, "source", project, plant)
                jpg_files += get_files(jpg_path, JPG_PATTERN)
        print("From {} media files".format(len(jpg_files)))
        src = Dataframe()
        src.add_medias(jpg_files)
        print("-" * 80)
        print("Saving to {}".format(file_path))
        src.save(file_path)
    print("-" * 80)
    print(src)

#    for batch in range(1, 42, 2):
    for batch in range(1, 42, 2):

        ref_batch = str(batch).rjust(2, "0")
        hyp_batch = str(batch + 1).rjust(2, "0")

        ref_files = []
        hyp_files = []

        ref_path = os.path.join(PATH, "inter-intra-lots", ref_batch)
        ref_files += get_files(ref_path, REF_PATTERN)

        hyp_path = os.path.join(PATH, "inter-intra-lots", hyp_batch)
        hyp_files += get_files(hyp_path, HYP_PATTERN)

        # Ref
        print("=" * 80)
        print("Loading ref")
        file_path = "/tmp/iag_{}.dtf".format(ref_batch)
        if RELOAD and os.path.exists(file_path):
            print("From {}".format(file_path))
            ref = Dataframe.from_file(file_path)
        else:
            print("From {} annotation files".format(len(ref_files)))
            ref = Dataframe()
            for ref_file in ref_files:
    #                print("\t{}".format(ref_file))
                ref.load_annot(ref_file)
            print("-" * 80)
            print("Saving to {}".format(file_path))
            ref.save(file_path)
        print("-" * 80)
        print(ref)

        # Hyp
        print("=" * 80)
        print("Loading hyp")
        file_path = "/tmp/iag_{}.dtf".format(hyp_batch)
        if RELOAD and os.path.exists(file_path):
            print("From {}".format(file_path))
            hyp = Dataframe.from_file(file_path)
        else:
            print("From {} annotation files".format(len(hyp_files)))
            hyp = Dataframe()
            for hyp_file in hyp_files:
                hyp.load_annot(hyp_file)
            print("-" * 80)
            print("Saving to {}".format(file_path))
            hyp.save(file_path)
        print("-" * 80)
        print(hyp)

        categories = [["plant 1.annotator"], ["plant 2.annotator"]]
        variables = ["iag.jaccard", "iag.accuracy annot"]
        params_list = [None]
        name = "iag_{}_{}".format(ref_batch, hyp_batch)
        test_eval.test_eval("iag", params_list, ref, hyp, src,
                            categories, variables, name)


if __name__ == "__main__":

    main()
