#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" Mapycs (Matics Python API) usage example """

import os

from mapycs import Dataframe
import test_eval

PATH = os.path.expanduser("~") + r"/matics/data/vl"
REF = "r1.txt"
SYSTEMS = {"h1": "h1.txt",
           "h1b": "h1b.txt",
           "h2": "h2.txt",
           "h3": "h3.txt"}


def main():

    """ Dataframe usage examples """
    # Ref
    print("=" * 80)
    print("Loading ref")
    ref = Dataframe()
    ref.load_annot(os.path.join(PATH, REF))
    print("-" * 80)
    print(ref)


#    # Hyp
    print("=" * 80)
    print("Loading hyp")
    hyp = Dataframe()
    for system, file_name in SYSTEMS.items():
        hyp.load_annot(os.path.join(PATH, file_name), {"systeme": system})
    print("-" * 80)
    print(hyp)

    categories = [["global.system"]]
    variables = ["locuteur.ptarget", "locuteur.Cllr", "eer.seuil", "eer.cdet",
                 "cdet.seuil", "cdet.cdet", "libre.seuil", "libre.cdet"]
    params_list = [
        None,
        {"metrics": []},
        {"params": {
                "miss_cost": 0.5,
                "fa_cost": 0.9,
                "ptarget": 0.05,
                "seuil": 0.3},
         "metrics": [
                    "estimate_ptarget",
                    "seuil_eer",
                    "seuil_cdet",
                    "seuil_libre"]}
    ]
    test_eval.test_eval("loc", params_list, ref, hyp, categories, variables)


if __name__ == "__main__":

    main()
