#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" Mapycs (Matics Python API) usage example """

from mapycs import Eval
from mapycs import CatStruct


def show_err(err):

    print("-" * 80)
    print("Error:")
    err = err.splitlines()
    if len(err) > 10:
        err = err[:10]
        err.append("...")
    for e in err:
        print("\t", e)


def do_eval(type_name, params, ref, hyp, src, file_path, cat, var):

    # Eval
    print("=" * 80)
    print("Evaluation")
    eva = None
    try:
        eva = Eval(type_name, params, ref, hyp, src)
    except RuntimeError as err:
        show_err(str(err))
        return
    print("-" * 80)
    print(eva)

    err = eva.get_err()
    if len(err) != 0:
        show_err(err)

    # Result
    print("-" * 80)
    res = eva.get_res_df()
    print(res)

    # Save
    print("-" * 80)
    print("Saving to {}".format(file_path))
    res.save(file_path)

    # Print the evaluation results
    print("=" * 80)
    cols_keys = res.get_cols_keys()
    cat2 = list()
    for cat_list in cat:
        cat_list2 = list()
        for cat_name in cat_list:
            if cat_name in cols_keys:
                cat_list2.append(cat_name)
        cat2.append(cat_list2)
    var2 = list()
    for var_name in var:
        if var_name in cols_keys:
            var2.append(var_name)
    results = CatStruct(res, cat2, var2)
    print(results)


def test_eval(type_name, params_list, ref, hyp, src, cat, var, name=""):

    eval_num = 0
    for params in params_list:
        if name != "":
            file_path = "/tmp/{}_{}.dtf".format(name, eval_num)
        else:
            file_path = "/tmp/{}_{}.dtf".format(type_name, eval_num)
        eval_num += 1
        do_eval(type_name, params, ref, hyp, src, file_path, cat, var)
