#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" Mapycs (Matics Python API) usage example """

import os

from mapycs import Dataframe
import test_eval

PATH = os.environ.get(r'HOME') + r"/.local/share/Evalomatic"


def main():

    """ Dataframe usage examples """

    # Ref
    print("=" * 80)
    print("Loading ref")
    ref_path = os.path.join(PATH, "trad-ref1.dtf")
    ref = Dataframe.from_file(ref_path)
    print("-" * 80)
    print(ref)


#    # Hyp
    print("=" * 80)
    print("Loading hyp")
    hyp_path = os.path.join(PATH, "trad-hyp.dtf")
    hyp = Dataframe.from_file(hyp_path)
    print("-" * 80)
    print(hyp)

    categories = [["global.system"], ["global.file"]]
    variables = ["single bleu.score", "multi bleu.score",
                 "ter.best reference score"]
    params_list = [
        {"metrics": []},
        {"params": {"bad_param": 20}, "metrics": ["bleu"]},
        None,
        {"params": {"beam": 20}, "metrics": ["bleu"]},
        {"params": {"beam": 100}, "metrics": ["ter"]}
    ]
    test_eval.test_eval("tra", params_list, ref, hyp, categories, variables)


if __name__ == "__main__":

    main()
