#include "p3det.h"
#include "p3df.h"

#include <Misc/strformat.h>
#include <Visualisations/detcurves.h>

namespace p3 {

PyTypeObject *p3::det::ptype;

PyMethodDef p3::det::methods[] = {
    { "plot_data", plot_data, METH_NOARGS,
      "plot_data(self)\n--\n\n:returns: columns count.\n"
    },
    {}
};
det::det() : det_curve(nullptr)
{

}

det::~det()
{
    if (nullptr != det_curve ) delete det_curve;
    det_curve = nullptr;
}

bool det::reg(PyObject *module)
{
    return type_register<det>(module, ptype, "Det", "");
}

int det::init(PyObject *self, PyObject *args, PyObject *)
{
    PyObject *odf;
    if(!PyArg_ParseTuple(args, "O!", dataframe::ptype, &odf))
        return 1;

    auto df = ((dataframe *)odf)->df;
    ((det *)self)->det_curve = new DetCurve(df);
    return 0;
}

PyObject *det::str(PyObject *)
{
    return PyUnicode_FromString("");
}

PyObject *det::plot_data(PyObject *self, PyObject *)
{
    auto        dtc = ((det *)self)->det_curve;
    if (nullptr == dtc) return nullptr;

    auto        ret = PyDict_New();

    auto        systems = dtc->getSystems();
    auto        sys_list = PyList_New(0);
    for (auto s : systems)
    {
        auto        sys_dict = PyDict_New();

        // Name
        auto        name = PyUnicode_FromString(s.getName().c_str());
        PyDict_SetItemString(sys_dict, "name", name);
        Py_DECREF(name);

        // EER
        if (s.getErr().valid)
        {
            auto        pts_dict = PyDict_New();

            auto        pfa = PyFloat_FromDouble(s.getErr().pfa);
            PyDict_SetItemString(pts_dict, "pfa", pfa);
            Py_DECREF(pfa);

            auto        pmiss = PyFloat_FromDouble(s.getErr().pmiss);
            PyDict_SetItemString(pts_dict, "pmiss", pmiss);
            Py_DECREF(pmiss);

            auto        cdet = PyFloat_FromDouble(s.getErr().cdet);
            PyDict_SetItemString(pts_dict, "cdet", cdet);
            Py_DECREF(cdet);

            auto        seuil = PyFloat_FromDouble(s.getErr().seuil);
            PyDict_SetItemString(pts_dict, "seuil", seuil);
            Py_DECREF(seuil);

            PyDict_SetItemString(sys_dict, "eer", pts_dict);
            Py_DECREF(pts_dict);
        }
        // CDET
        if (s.getCdet().valid)
        {
            auto        pts_dict = PyDict_New();

            auto        pfa = PyFloat_FromDouble(s.getCdet().pfa);
            PyDict_SetItemString(pts_dict, "pfa", pfa);
            Py_DECREF(pfa);

            auto        pmiss = PyFloat_FromDouble(s.getCdet().pmiss);
            PyDict_SetItemString(pts_dict, "pmiss", pmiss);
            Py_DECREF(pmiss);

            auto        cdet = PyFloat_FromDouble(s.getCdet().cdet);
            PyDict_SetItemString(pts_dict, "cdet", cdet);
            Py_DECREF(cdet);

            auto        seuil = PyFloat_FromDouble(s.getCdet().seuil);
            PyDict_SetItemString(pts_dict, "seuil", seuil);
            Py_DECREF(seuil);

            PyDict_SetItemString(sys_dict, "cdet", pts_dict);
            Py_DECREF(pts_dict);
        }
        // Libre
        if (s.getLibre().valid)
        {
            auto        pts_dict = PyDict_New();

            auto        pfa = PyFloat_FromDouble(s.getLibre().pfa);
            PyDict_SetItemString(pts_dict, "pfa", pfa);
            Py_DECREF(pfa);

            auto        pmiss = PyFloat_FromDouble(s.getLibre().pmiss);
            PyDict_SetItemString(pts_dict, "pmiss", pmiss);
            Py_DECREF(pmiss);

            auto        seuil = PyFloat_FromDouble(s.getLibre().seuil);
            PyDict_SetItemString(pts_dict, "seuil", seuil);
            Py_DECREF(seuil);

            PyDict_SetItemString(sys_dict, "libre", pts_dict);
            Py_DECREF(pts_dict);
        }
        // Points
        auto        points = s.getPoints();
        auto        pts_list = PyList_New(0);
        for (auto pt : points)
        {
            auto        pts_dict = PyDict_New();

            auto        pfa = PyFloat_FromDouble(pt.first);
            PyDict_SetItemString(pts_dict, "pfa", pfa);
            Py_DECREF(pfa);

            auto        pmiss = PyFloat_FromDouble(pt.second);
            PyDict_SetItemString(pts_dict, "pmiss", pmiss);
            Py_DECREF(pmiss);

            PyList_Append(pts_list, pts_dict);
            Py_DECREF(pts_dict);
        }
        PyDict_SetItemString(sys_dict, "points", pts_list);
        Py_DECREF(pts_list);

        PyList_Append(sys_list, sys_dict);
        Py_DECREF(sys_dict);
    }
    PyDict_SetItemString(ret, "systems", sys_list);
    Py_DECREF(sys_list);

    return ret;
}

} // namespace p3
