#ifndef PYTHON3_H
#define PYTHON3_H

#define PY_SSIZE_T_CLEAN
#include "p3medialoader.h"

#include <Python.h>

PyMODINIT_FUNC PyInit_mapycs();

namespace p3 {
template<typename T> PyObject *mapycs_new(PyTypeObject *type, PyObject *, PyObject *)
{
    ffmpeg::init();
    medialoader = MediaLoader::get_instance();

    PyObject *alloc = type->tp_alloc(type, 0);
    PyObject base = *alloc;
    T *obj = new(alloc) T();
    obj->ob_base = base;
    return &obj->ob_base;
}

template<typename T> void mapycs_free(void *self)
{
  T *t = (T *)self;
  t->~T();
}

template<typename T> int type_register(PyObject *module, PyTypeObject *&t, const char *name, const char *doc)
{
    std::string fullname = std::string("mapycs.") + name;
    t = new PyTypeObject();
    t->tp_name = strdup(fullname.c_str());
    t->tp_doc = doc;
    t->tp_basicsize = sizeof(T);
    t->tp_flags = Py_TPFLAGS_DEFAULT;
    t->tp_new = mapycs_new<T>;
    t->tp_free = mapycs_free<T>;
    t->tp_init = T::init;
    t->tp_str = T::str;
    t->tp_methods = T::methods;

    if(PyType_Ready(t) < 0)
      return 1;

    Py_INCREF(t);
    PyModule_AddObject(module, name, (PyObject *)t);
    return 0;
}

static inline std::string tostr(PyObject *o)
{
    Py_ssize_t size;
    const char *data = PyUnicode_AsUTF8AndSize(o, &size);
    return std::string(data, data+size);
}
}

#endif // PYTHON3_H
